****************************************************************************
*********                 ANALYZING THE DISTRIBUTIONAL             *********
*********                      EFFECT OF TRADE                     ********* 
****************************************************************************

* Data source: ETHIOPIA household survey and trade policy data.
*Effect of change in tariff in Ethiopia.  
*simplified do file not using survey commands in stata (s.e. not available)

	clear all
	set mem 300m
	set matsize 800
	graph drop _all
	
* Open database
	
	cd "$input/Chapter6/Datasets"

********* PRELIMINARY STEP *********


**** TRADE POLICY DATA
* load trade policy information on tariffs
	use tariff_9501.dta, clear

* describe the dataset
describe

* aggregate HS information to calculate average tariff by product group using imports as weights. 
  collapse  tariff_1995 tariff_2001 [w=imports], by (type)

* calculate percentage points change in tariff between 1995 and 2001, this will give the change in the price of the good
** This assumes that domestic prices = WorldPrice*(1+tariff). 
** Therefore the domestic price in 1995 is WorldPrice*(1+tariff_1995) and in 2001 is WorldPrice*(1+tariff_2001)
** Thus the % difference in domestic price is given by:
   gen delta_price=  ((1+ tariff_2001)/ (1+ tariff_1995))-1

* Saving trade policy file by product group
sort type
save "deltaprices.dta", replace



**** HOUSEHOLD DATA

use "Ethiopia_hhsurvey.dta", clear

* describe the dataset
describe 

* construct 2 local variables with names of income and expenditure categories
local inc_categ "teff wheat barley maize sorghum coffee chat livestoc otherag enter wage remitt otherinc" 
local exp_categ "alcholic barley beverage chat coffee fishing fuelwood goods livestock maize oilseed otheragr pulses notrade sorghum teff tobacco wheat"

* construct weights taking into account household size 
  gen wgt_ind=wgt*hhld_siz

* categorize the households by centiles depending on their per capita expenditures 
** create total expenditures (including subsistance)
   egen totexpend_hh=rsum(expend* subsistence_inc)
** create per capita expenditure taking into account equivalence scales
   gen pcexp_eq=totexpend_hh/eq_scale
** building percentiles (by individuals, not households)
   xtile decile= pcexp_eq [w=wgt_ind], nq(10)


* transform expenditures in per capita expenditures 
foreach x of local exp_cat {
        replace expend`x'= expend`x'/eq_scale
        }
* transform income in per capita income
foreach x of local inc_cat {
        replace i_`x'= i_`x'/eq_scale
        }        
replace subsistence_inc = subsistence_inc/eq_scale

        
* saving the data
save "temp.dta", replace

***** CONSUMPTION EFFECT


* keep only variables needed for consumption
keep  killil zone wereda town keftegna kebele ea hhld_id stratum wgt* subsistence* expend* decile pcexp_eq gender


* calculate mean total expenditures by each percentile 
egen totexp=rsum(expend* subsistence)
  
* reshaping data to have product groups as a variable
reshape long  expend, i ( killil zone wereda town keftegna kebele ea hhld_id stratum gender) j(type) string

* merge price changes from trade policy data
sort type
merge type using "deltaprices.dta"
drop _merge

* assuming that prices of non traded products are not affeted by trade policy
replace  delta_price=0 if delta_price==.

* calculating households expenditures with new prices
gen  expendnew=expend*(1+delta_price)



* collapsing everyting at the household level 
collapse (sum) expend expendnew (mean) decile pcexp_eq totexp wgt_ind, by (killil zone wereda town keftegna kebele ea hhld_id)

* freezing dataset for later 
preserve

* calculate the consumption effect over total expenditures (including subsistence)
** this is the % change in real income of each household due to changes in prices (from tariffs)
gen cons_effect= -(expendnew- expend)/ totexp

* approximating weights because non-integer in lpoly
gen ww=int(wgt_ind)

* take log of pc expenditure for the graph
gen lnpcexp=ln( pcexp_eq)

* graph the consumption effect by log of per capita expenditures
lpoly  cons_effect lnpcexp [w=ww], bw(0.05)

cd "$input/Chapter6/Applications/Results"
graph export "figure_6.2.eps", as(eps) preview(on) replace

cd "$input/Chapter6/Datasets"

* un-pause by pressing "q"
*pause 

* saving data  
sort killil zone wereda town keftegna kebele ea hhld_id
save "result_hh.dta", replace

* restoring the data 
restore

* collapsing everyting at the decile level
collapse expend expendnew pcexp_eq totexp [w=wgt_ind], by (decile) 

* calculate the consumption effect over total expenditures (including subsistence)
** this is the % change in real income of each household due to changes in prices (from tariffs)
gen cons_effect= -(expendnew- expend)/ totexp

* saving data 
keep decile cons*
sort decile
save "result_decile.dta", replace


***** INCOME EFFECT (sales of agricultural products)
* assume no rescaling of income needed to match expenditures

use "temp.dta", clear


* keep only variables needed for consumption
keep  killil zone wereda town keftegna kebele ea hhld_id stratum wgt* subsistence* i_* decile pcexp_eq 

* calculate mean total expenditures by each percentile 
egen totinc=rsum(i_* subsistence)
  
* reshaping data to have product groups as a variable
reshape long  i_, i ( killil zone wereda town keftegna kebele ea hhld_id stratum subsistence) j(type) string

* merge price changes from trade policy data
sort type
merge type using "deltaprices.dta"
drop _merge

* assuming that prices of wages and services are not affeted by trade policy
replace  delta_price=0 if delta_price==.

* calculating households income with new prices
gen  i_new=i_*(1+delta_price)


* collapsing everyting at the household level 
collapse (sum) i_ i_new (mean) decile pcexp_eq totinc wgt_ind subsistence, by (killil zone wereda town keftegna kebele ea hhld_id)

* freezing dataset for later 
preserve

* calculate the income effect over total income (including subsistence)
** this is the % change in real income of each household due to changes in prices (from tariffs)
gen inc_effect= (i_new- i_)/ totinc

* approximating weights because non-integer in lpoly
gen ww=int(wgt_ind)

* take log of pc expenditure for the graph
gen lnpcexp=ln( pcexp_eq)

* graph the consumption effect by log of per capita expenditures
lpoly  inc_effect lnpcexp [w=ww], bw(0.05)

cd "$input/Chapter6/Applications/Results"
graph export "figure_6.3.eps", as(eps) preview(on) replace

cd "$input/Chapter6/Datasets"

*pause 

* merging with consumption effects and saving
keep killil zone wereda town keftegna kebele ea hhld_id inc_effect
sort killil zone wereda town keftegna kebele ea hhld_id
merge killil zone wereda town keftegna kebele ea hhld_id using "result_hh.dta"
drop _merge
egen overall=rsum(inc_effect cons_effect)
sort killil zone wereda town keftegna kebele ea hhld_id
save "result_hh.dta", replace



* graphs for shares of subsistence and wages
use "temp.dta", clear
keep  killil zone wereda town keftegna kebele ea hhld_id stratum wgt* subsistence* i_* decile pcexp_eq gender

* setting variable to zero when missing
replace subsistence=0 if subsistence==.
replace i_wage=0 if i_wage==.

* calculating shares
egen totinc=rsum(i_* subsistence)
gen share_subsistence= subsistence_inc/totinc
gen share_wage= i_wage/totinc


* approximating weights because non-integer in lpoly
gen ww=int(wgt_ind)

* take log of pc expenditure for the graph
gen lnpcexp=ln( pcexp_eq)



lpoly  share_subsistence lnpcexp [w=ww], bw(0.3)

cd "$input/Chapter6/Applications/Results"
graph export "figure_6.4_a.eps", as(eps) preview(on) replace

cd "$input/Chapter6/Datasets"

*pause

lpoly  share_wage lnpcexp [w=ww], bw(0.3)

cd "$input/Chapter6/Applications/Results"
graph export "figure_6.4_b.eps", as(eps) preview(on) replace

cd "$input/Chapter6/Datasets"

*pause

* restoring the data 
restore

* collapsing everyting at the decile level
collapse i_ i_new pcexp_eq totinc [w=wgt_ind], by (decile) 

* calculate the income effect over total income (including subsistence)
* this is the % change in real income of each household due to changes in prices (from tariffs)
gen inc_effect= (i_new- i_)/ totinc


********* OVERALL RESULTS

* merging with consumption data and saving 
keep decile inc*
sort decile
merge decile using "result_decile.dta"
drop _merge

* calculating overall effects
egen overall_effect=rsum(cons inc)

* listing results by decile
list decile *

*pause


* loading the results at the hh level
use "result_hh.dta",clear

*plot over regions 
graph box  overall [w= wgt_ind], over ( killil ,   label(labsize(vsmall)))

cd "$input/Chapter6/Applications/Results"
graph export "figure_6.5.eps", as(eps) preview(on) replace

cd "$input/Chapter6/Datasets"


*pause

*pause off


use "EMS.dta", clear
collapse income tariff [w=prod_exp] , by ( strata_id comm_id weights) 
xtile centile = income [w=weights], nquantiles(100)
collapse tariff [w=weights] , by ( centile)
lowess tariff centile

cd "$input/Chapter6/Applications/Results"
graph export "figure_6.6.eps", as(eps) preview(on) replace

cd "$input/Chapter6/Datasets"


graph drop _all

exit
exit
exit
